These modulation transfer functions (MTF) star files are copied from [RELION](https://github.com/3dem/relion/tree/master/data) and also downloaded directly from [Gatan's website](https://www.gatan.com/techniques/cryo-em#MTF).